@@ -1,3 +1,11 @@
+"""
+    Copyright (C) 2017-2018 Team Kodi
+    This file is part of Kodi - kodi.tv
+
+    SPDX-License-Identifier: GPL-3.0-only
+    See LICENSES/README.md for more information.
+"""
+
 import importlib
 import os
 import pkgutil
@@ -7,6 +15,10 @@ REL_PATH = ""
 
 
 def has_transparency(im):
+    """Check the transparency(aplha layer) in the given image
+
+        :im: PIL.Image object
+    """
     try:
         if im.mode == "RGBA":
             alpha = im.split()[-1]
@@ -15,13 +27,14 @@ def has_transparency(im):
                                            for x in enumerate(listdata) if x[1] < 255)
             if first_transparent_pixel is not None:
                 return True
-        else:
-            return False
+        return False
     except StopIteration:
         return False
 
 
 def load_plugins():
+    """Load the reporter plugins
+    """
     plugins_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "plugins")
     sys.path.append(plugins_dir)
     for _, package_name, _ in pkgutil.iter_modules([plugins_dir]):
@@ -30,5 +43,7 @@ def load_plugins():
 
 
 def relative_path(file_path):
+    """Return the relative_path of the file
+    """
     path_to_print = file_path[len(REL_PATH):]
     return ".{}".format(path_to_print)
